==> V2.1.0.tar.gz: grasscutterswebdashboard/src/main/java/top/cyqi/websocket/ServerUtils.java <==
package top.cyqi.websocket;

import emu.grasscutter.Grasscutter;
import emu.grasscutter.command.CommandMap;
import emu.grasscutter.game.player.Player;
import io.javalin.websocket.WsMessageContext;
import top.cyqi.GrasscuttersWebDashboard;
import top.cyqi.handlers.WebToolsMessageHandler;
import top.cyqi.websocket.json.PlayerData;
import top.cyqi.websocket.json.PlayerWebKey;
import top.cyqi.websocket.json.WSData;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


public class ServerUtils {

    public static Map<String, PlayerWebKey> tempPlayersData = new HashMap<>();

    static void DealMessage(String type, String data, WsMessageContext wsMessageContext) {
        String ws_id = WebSocketServer.ClitenContextMap.get(wsMessageContext);
        switch (type) {
            case "CMD" -> {
                Grasscutter.getLogger().info("[WEB控制台] 执行" + ws_id + "的命令:" + data);
                CommandMap commandMap = Grasscutter.getGameServer().getCommandMap();
                commandMap.invoke(null, null, data);
            }
            case "State" -> wsMessageContext.send(new WSData("BaseData", GrasscuttersWebDashboard.baseData));
            case "Player" -> showPlayerList(wsMessageContext);
        }
    }

    public static void showPlayerList(WsMessageContext wsMessageContext) {
        Map<Integer, Player> playerMap = GrasscuttersWebDashboard.getGameServer().getPlayers();
        //循环遍历所有玩家
        List<PlayerData> playerDatas = new ArrayList<>();
        for (Map.Entry<Integer, Player> entry : playerMap.entrySet()) {
            Player player = entry.getValue();
            PlayerData playerData = new PlayerData();
            playerData.uid = player.getUid();
            playerData.signature = player.getSignature();
            playerData.nickname = player.getNickname();
            playerData.headImage = player.getHeadImage();
            playerData.worldLevel = player.getWorldLevel();
            playerData.Level = player.getLevel();
            playerData.pos = player.getPos().toString();
            playerData.SceneId = player.getSceneId();
            playerDatas.add(playerData);
        }
        wsMessageContext.send(new WSData("PlayerList", playerDatas));
    }

    public static void WebToolsDealMessage(Player player, String type, String data, WsMessageContext wsMessageContext) {
        switch (type) {
            case "CMD" -> {
                WebToolsMessageHandler resultCollector = new WebToolsMessageHandler();
                resultCollector.wsMessageContext = wsMessageContext;
                resultCollector.player = player;
                player.setMessageHandler(resultCollector);
                CommandMap commandMap = Grasscutter.getGameServer().getCommandMap();
                try {
                    commandMap.invoke(player, player, data);
                } catch (Exception e) {
                    wsMessageContext.send(new WSData("error", e.getMessage()));
                }

            }
            case "Player" -> showPlayerList(wsMessageContext);
        }
    }
}

==> V2.2.1.tar.gz: grasscutterswebdashboard/src/main/java/top/cyqi/websocket/ServerUtils.java <==
package top.cyqi.websocket;

import emu.grasscutter.Grasscutter;
import emu.grasscutter.command.CommandMap;
import emu.grasscutter.database.DatabaseHelper;
import emu.grasscutter.game.player.Player;
import emu.grasscutter.game.quest.GameMainQuest;
import emu.grasscutter.game.quest.enums.ParentQuestState;
import emu.grasscutter.game.quest.enums.QuestState;
import io.javalin.websocket.WsMessageContext;
import top.cyqi.GrasscuttersWebDashboard;
import top.cyqi.handlers.WebToolsMessageHandler;
import top.cyqi.websocket.json.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


public class ServerUtils {

    public static Map<String, PlayerWebKey> tempPlayersData = new HashMap<>();

    static void DealMessage(String type, String data, WsMessageContext wsMessageContext) {
        String ws_id = WebSocketServer.ClitenContextMap.get(wsMessageContext);
        switch (type) {
            case "CMD" -> {
                Grasscutter.getLogger().info("[WEB控制台] 执行" + ws_id + "的命令:" + data);
                CommandMap commandMap = Grasscutter.getGameServer().getCommandMap();
                commandMap.invoke(null, null, data);
            }
            case "State" -> wsMessageContext.send(new WSData("BaseData", GrasscuttersWebDashboard.baseData));
            case "Player" -> showPlayerList(wsMessageContext);
        }
    }

    public static void showPlayerList(WsMessageContext wsMessageContext) {
        Map<Integer, Player> playerMap = GrasscuttersWebDashboard.getGameServer().getPlayers();
        //循环遍历所有玩家
        List<PlayerData> playerDatas = new ArrayList<>();
        for (Map.Entry<Integer, Player> entry : playerMap.entrySet()) {
            Player player = entry.getValue();
            PlayerData playerData = new PlayerData();
            playerData.uid = player.getUid();
            playerData.signature = player.getSignature();
            playerData.nickname = player.getNickname();
            playerData.headImage = player.getHeadImage();
            playerData.worldLevel = player.getWorldLevel();
            playerData.Level = player.getLevel();
            playerData.pos = player.getPos().toString();
            playerData.SceneId = player.getSceneId();
            playerDatas.add(playerData);
        }
        wsMessageContext.send(new WSData("PlayerList", playerDatas));
    }

    public static void WebToolsDealMessage(Player player, String type, String data, WsMessageContext wsMessageContext) {
        switch (type) {
            case "CMD" -> {
                WebToolsMessageHandler resultCollector = new WebToolsMessageHandler();
                resultCollector.wsMessageContext = wsMessageContext;
                resultCollector.player = player;
                player.setMessageHandler(resultCollector);
                CommandMap commandMap = Grasscutter.getGameServer().getCommandMap();
                try {
                    commandMap.invoke(player, player, data);
                } catch (Exception e) {
                    wsMessageContext.send(new WSData("error", e.getMessage()));
                }

            }
            case "Player" -> showPlayerList(wsMessageContext);
            case "DelQuest" -> {
                List<GameMainQuest> gameMainQuests = DatabaseHelper.getAllQuests(player);
                //遍历所有任务
                for (GameMainQuest gameMainQuest : gameMainQuests) {
                    //如果任务id相同,或者全部删除
                    if (data.equals("ALL")|| data.contains(gameMainQuest.getParentQuestId() + "")) {
                        //删除任务
                        DatabaseHelper.deleteQuest(gameMainQuest);
                        wsMessageContext.send(new WSData("success", "删除'" + gameMainQuest.getParentQuestId() + "'成功，请退出重进"));
                        return;
                    }
                }
                wsMessageContext.send(new WSData("error", "任务不存在"));
            }
        }
    }
}
